<?php
//
//  Nagios Core Config Manager
//  Copyright (c) 2010-2018 Nagios Enterprises, LLC
//
//  File: session.inc.php
//  Desc: Handles all the definitions and includes for the CCM. Also does the authentication
//        using the function in auth.inc.php.
//

// Main includes 
require_once(BASEDIR.'config.inc.php'); 
require_once(INCDIR.'common_functions.inc.php'); 
require_once(INCDIR.'language.inc.php'); 
require_once(INCDIR.'auth.inc.php'); 
require_once(INCDIR.'hidden_overlay_functions.inc.php'); 

// Updated NagiosQL classes
require_once(CLASSDIR.'config.class.php'); 
require_once(CLASSDIR.'data.class.php'); 
require_once(CLASSDIR.'mysqldb.class.php');
require_once(CLASSDIR.'import.class.php'); 

// New CCM classes
require_once(CLASSDIR.'db.class.php');
require_once(CLASSDIR.'form.class.php');

// CCM main includes 
require_once(TPLDIR.'ccm_table.php');
require_once(INCDIR.'page_router.inc.php');

// Set default result limits 
define('DEFAULT_PAGELIMIT', $CFG['default_pagelimit']); 
$_SESSION['default_limit'] = DEFAULT_PAGELIMIT;

// Global classe instances
$ccmDB = new db();

// Load CCM config settings
// TODO: This should be changed to "ccm_cfg" to not be confused with Nagios XI
$CFG['settings'] = array(); 
$settings = $ccmDB->query("SELECT * FROM tbl_settings;"); 
foreach ($settings as $s) { 
    $CFG[$s['category']][$s['name']] = $s['value']; 
}

// Add data to the session
// =======================
$_SESSION['SETS'] = $CFG;
$_SESSION['domain'] = 1; // Currently we only support single domain configs 
if (!isset($_SESSION['limit'])) {
    $_SESSION['limit'] = $CFG['common']['pagelines'];
}
$_SESSION['pagelimit'] = $_SESSION['limit'];

// Process $_POST an $_GET variables 
$escape_request_vars = true; 
ccm_grab_request_vars();

// Initialize base global objects
$myDataClass = new nagdata;
$myConfigClass = new nagconfig;
$myDBClass = new mysqldb; 
$myImportClass = new nagimport;

// Reference objects inside of global objects
$myDataClass->myDBClass =& $myDBClass;
$myDataClass->myConfigClass =& $myConfigClass;
$myConfigClass->myDBClass =& $myDBClass;
$myConfigClass->myDataClass =& $myDataClass;
$myImportClass->myDataClass =& $myDataClass;
$myImportClass->myDBClass =& $myDBClass;
$myImportClass->myConfigClass =& $myConfigClass;

// NagiosQL authentication
$AUTH = check_auth();

// Global unique element ID used as a counter 
$unique = 100;

// Nagios XI language settings
if (ENVIRONMENT == "nagiosxi") {
    ccm_init_language(); 
}
    
// Debug mode...
$debug = ccm_grab_request_var('debug', false);
if ($debug == 'enable') { $_SESSION['debug'] = true; }
if ($debug == 'verbose') { $_SESSION['debug'] = 'verbose'; }
if ($debug == 'disable') { unset($_SESSION['debug']); }